@@ -9,10 +9,6 @@ from fast_tracker import config, Layer, ComponentType, Log, LogItem
 from fast_tracker.trace.context import get_context
 from fast_tracker.trace.tags import Tag
 
-custom_user_code = ""
-custom_tenant_code = ""
-custom_env_code = ""
-
 
 class FastTracker:
     def __init__(self):
@@ -58,8 +54,7 @@ class FastTracker:
         获取 env_code 值
         :return:
         """
-        global custom_env_code
-        return custom_env_code if custom_env_code else config.env_code
+        return config.custom_env_code if config.custom_env_code else config.env_code
 
     @env_code.setter
     def env_code(self, env_code: str = ""):
@@ -69,9 +64,7 @@ class FastTracker:
         :return:
         """
         if env_code:
-            global custom_env_code
-            custom_env_code = env_code
-        config.set_env_code(env_code)
+            config.custom_env_code = env_code
 
     @property
     def tenant_code(self):
@@ -79,8 +72,7 @@ class FastTracker:
         获取 tenant_code 值
         :return:
         """
-        global custom_tenant_code
-        return custom_tenant_code if custom_tenant_code else config.tenant_code
+        return config.custom_tenant_code if config.custom_tenant_code else config.tenant_code
 
     @tenant_code.setter
     def tenant_code(self, tenant_code: str = ""):
@@ -90,9 +82,7 @@ class FastTracker:
         :return:
         """
         if tenant_code:
-            global custom_tenant_code
-            custom_tenant_code = tenant_code
-        config.set_tenant_code(tenant_code)
+            config.custom_tenant_code = tenant_code
 
     @property
     def user_code(self):
@@ -100,8 +90,7 @@ class FastTracker:
         获取 user_code 值
         :return:
         """
-        global custom_user_code
-        return custom_user_code if custom_user_code else config.user_code
+        return config.custom_user_code if config.custom_user_code else config.user_code
 
     @user_code.setter
     def user_code(self, user_code: str = ""):
@@ -111,9 +100,7 @@ class FastTracker:
         :return:
         """
         if user_code:
-            global custom_user_code
-            custom_user_code = user_code
-        config.set_user_code(user_code)
+            config.custom_user_code = user_code
 
     @property
     def service_name(self):
